[![build](https://github.com/plasticuproject/fnv1a/actions/workflows/tests.yml/badge.svg)](https://github.com/plasticuproject/fnv1a/actions/workflows/tests.yml)
[![Python 3.8](https://img.shields.io/badge/python-3.8+-blue.svg)](https://www.python.org/downloads/release/python-380/)
![GitHub](https://img.shields.io/github/license/plasticuproject/fnv1a)
[![PyPI version](https://badge.fury.io/py/fnv1a.svg)](https://badge.fury.io/py/fnv1a)
[![Downloads](https://pepy.tech/badge/fnv1a)](https://pepy.tech/project/fnv1a)
[![Coverage Status](https://coveralls.io/repos/github/plasticuproject/fnv1a/badge.svg?branch=master)](https://coveralls.io/github/plasticuproject/fnv1a?branch=master)
[![CodeQL](https://github.com/plasticuproject/fnv1a/actions/workflows/codeql.yml/badge.svg)](https://github.com/plasticuproject/fnv1a/actions/workflows/codeql.yml)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=plasticuproject_fnv1a&metric=alert_status)](https://sonarcloud.io/dashboard?id=plasticuproject_fnv1a)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=plasticuproject_fnv1a&metric=security_rating)](https://sonarcloud.io/dashboard?id=plasticuproject_fnv1a)

# fnv1a

OOP implimentation of a 64 bit FNV-1a hashing algorithm, where you can create hash
objects with "states" and "dehash" a list of "states" to recreate the original string.
It's completely useless and ridiculous and it makes no sense, but I was really bored.

```pip install fnv1a```

